@@ -32,7 +32,7 @@ package Apache2::AMFWURFLFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "3.20";
+  $VERSION= "3.21";
   my $CommonLib = new Apache2::AMFCommonLib ();
  
   my %Capability;
@@ -44,60 +44,38 @@ package Apache2::AMFWURFLFilter;
   my %PatchArray_id;
   my %MobileArray;
   my %PCArray;
-  $MobileArray{'mobile'}='mobile';
-  $MobileArray{'symbian'}='mobile';
-  $MobileArray{'midp'}='mobile';
   $MobileArray{'android'}='mobile';
-  $MobileArray{'phone'}='mobile';
-  $MobileArray{'ipod'}='mobile';
-  $MobileArray{'google'}='mobile';
-  $MobileArray{'novarra'}='mobile';
-  $MobileArray{'htc'}='mobile';
-  $MobileArray{'windows ce'}='mobile';
-  $MobileArray{'palm'}='mobile';
-  $MobileArray{'lge'}='mobile';
+  $MobileArray{'bolt'}='mobile';
   $MobileArray{'brew'}='mobile';
-  $MobileArray{'webos'}='mobile';
-  $MobileArray{'kddi'}='mobile';
-  $MobileArray{'nokia'}='mobile';
-  $MobileArray{'sanyo'}='mobile';
+  $MobileArray{'docomo'}='mobile';
   $MobileArray{'foma'}='mobile';
   $MobileArray{'hiptop'}='mobile';
-  $MobileArray{'kindle'}='mobile';
-  $MobileArray{'tablet'}='mobile';
-  $MobileArray{'maemo'}='mobile';
-  $MobileArray{'softbank'}='mobile';
-  $MobileArray{'mobile'}='mobile';
-  $MobileArray{'symbian'}='mobile';
-  $MobileArray{'midp'}='mobile';
-  $MobileArray{'android'}='mobile';
-  $MobileArray{'phone'}='mobile';
-  $MobileArray{'ipod'}='mobile';
-  $MobileArray{'google'}='mobile';
-  $MobileArray{'novarra'}='mobile';
   $MobileArray{'htc'}='mobile';
-  $MobileArray{'windows ce'}='mobile';
-  $MobileArray{'palm'}='mobile';
-  $MobileArray{'lge'}='mobile';
-  $MobileArray{'brew'}='mobile';
-  $MobileArray{'webos'}='mobile';
+  $MobileArray{'ipod'}='mobile';
   $MobileArray{'kddi'}='mobile';
-  $MobileArray{'nokia'}='mobile';
-  $MobileArray{'sanyo'}='mobile';
-  $MobileArray{'foma'}='mobile';
-  $MobileArray{'hiptop'}='mobile';
   $MobileArray{'kindle'}='mobile';
-  $MobileArray{'tablet'}='mobile';
+  $MobileArray{'lge'}='mobile';
   $MobileArray{'maemo'}='mobile';
-  $MobileArray{'softbank'}='mobile';
+  $MobileArray{'midp'}='mobile';
+  $MobileArray{'mobile'}='mobile';
   $MobileArray{'netfront'}='mobile';
-  $MobileArray{'sony'}='mobile';
+  $MobileArray{'nintendo'}='mobile';
+  $MobileArray{'nokia'}='mobile';
+  $MobileArray{'novarra'}='mobile';
+  $MobileArray{'palm'}='mobile';
+  $MobileArray{'phone'}='mobile';
   $MobileArray{'playstation'}='mobile';
   $MobileArray{'samsung'}='mobile';
-  $MobileArray{'bolt'}='mobile';
-  $MobileArray{'nintendo'}='mobile';
+  $MobileArray{'sanyo'}='mobile';
+  $MobileArray{'softbank'}='mobile';
+  $MobileArray{'sony'}='mobile';
+  $MobileArray{'symbian'}='mobile';
+  $MobileArray{'tablet'}='mobile';
+  $MobileArray{'webos'}='mobile';
+  $MobileArray{'windows ce'}='mobile';
+  $MobileArray{'wireless'}='mobile';
   $MobileArray{'xv6875.1'}='mobile';
-  $MobileArray{'nokia'}='mobile';
+
   $PCArray{'msie'}='msie';
   $PCArray{'msie 5'}='msie_5';
   $PCArray{'msie 6'}='msie_6';
@@ -676,7 +654,6 @@ sub handler {
     $id=$CommonLib->readCookie($cookie);
     $user_agent=lc($user_agent);
     $user_agent=$CommonLib->androidDetection($user_agent);
-    $user_agent=$CommonLib->botDetection($user_agent);    
 
     if ($cacheSystem->restore( 'wurfl-ua', $user_agent )) {
           #
@@ -710,9 +687,12 @@ sub handler {
 								$mobile=1;
 							}
 						}
-						if ($mobile==0) {						
+						if ($mobile==0) {
+							$f->log->warn("$user_agent");
+							$user_agent=$CommonLib->botDetection($user_agent);    
+							$f->log->warn("$user_agent");
 							$id=IdentifyPCUAMethod($user_agent);
-						}			            
+						} 
 					}
 					if ($id) {}else{$id="";};
 					if ($id eq "") { 
