@@ -33,7 +33,7 @@ package Apache2::AMFWURFLFilterMemcached;
 
   use vars qw($VERSION);
   my $CommonLib = new Apache2::AMFCommonLib ();
-  $VERSION= "3.20";
+  $VERSION= "3.21";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -43,37 +43,38 @@ package Apache2::AMFWURFLFilterMemcached;
   my %PatchArray_id;
   my %MobileArray;
   my %PCArray;
-  $MobileArray{'mobile'}='mobile';
-  $MobileArray{'symbian'}='mobile';
-  $MobileArray{'midp'}='mobile';
   $MobileArray{'android'}='mobile';
-  $MobileArray{'phone'}='mobile';
-  $MobileArray{'ipod'}='mobile';
-  $MobileArray{'google'}='mobile';
-  $MobileArray{'novarra'}='mobile';
-  $MobileArray{'htc'}='mobile';
-  $MobileArray{'windows ce'}='mobile';
-  $MobileArray{'palm'}='mobile';
-  $MobileArray{'lge'}='mobile';
+  $MobileArray{'bolt'}='mobile';
   $MobileArray{'brew'}='mobile';
-  $MobileArray{'webos'}='mobile';
-  $MobileArray{'kddi'}='mobile';
-  $MobileArray{'nokia'}='mobile';
-  $MobileArray{'sanyo'}='mobile';
+  $MobileArray{'docomo'}='mobile';
   $MobileArray{'foma'}='mobile';
   $MobileArray{'hiptop'}='mobile';
+  $MobileArray{'htc'}='mobile';
+  $MobileArray{'ipod'}='mobile';
+  $MobileArray{'kddi'}='mobile';
   $MobileArray{'kindle'}='mobile';
-  $MobileArray{'tablet'}='mobile';
+  $MobileArray{'lge'}='mobile';
   $MobileArray{'maemo'}='mobile';
-  $MobileArray{'softbank'}='mobile';
+  $MobileArray{'midp'}='mobile';
+  $MobileArray{'mobile'}='mobile';
   $MobileArray{'netfront'}='mobile';
-  $MobileArray{'sony'}='mobile';
+  $MobileArray{'nintendo'}='mobile';
+  $MobileArray{'nokia'}='mobile';
+  $MobileArray{'novarra'}='mobile';
+  $MobileArray{'palm'}='mobile';
+  $MobileArray{'phone'}='mobile';
   $MobileArray{'playstation'}='mobile';
   $MobileArray{'samsung'}='mobile';
-  $MobileArray{'bolt'}='mobile';
-  $MobileArray{'nintendo'}='mobile';
+  $MobileArray{'sanyo'}='mobile';
+  $MobileArray{'softbank'}='mobile';
+  $MobileArray{'sony'}='mobile';
+  $MobileArray{'symbian'}='mobile';
+  $MobileArray{'tablet'}='mobile';
+  $MobileArray{'webos'}='mobile';
+  $MobileArray{'windows ce'}='mobile';
+  $MobileArray{'wireless'}='mobile';
   $MobileArray{'xv6875.1'}='mobile';
-  $MobileArray{'nokia'}='mobile';
+
   $PCArray{'msie'}='msie';
   $PCArray{'msie 5'}='msie_5';
   $PCArray{'msie 6'}='msie_6';
@@ -640,7 +641,6 @@ sub handler {
     $user_agent=lc($user_agent);
     
     $user_agent=$CommonLib->androidDetection($user_agent);
-    $user_agent=$CommonLib->botDetection($user_agent);    
     if ($id eq ""){
                   if ($user_agent) {
 	  			    if ($mobile==0) {
@@ -649,7 +649,9 @@ sub handler {
 								$mobile=1;
 							}
 						}
+						
 						if ($mobile==0) {
+							$user_agent=$CommonLib->botDetection($user_agent);    
 							$id=IdentifyPCUAMethod($user_agent);
 						}			            
 					}
